@@ -1,14 +1,14 @@
 use std::collections::BTreeMap;
 
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::AddressKey,
     serde_raw::CheckAccountsRaw,
 };
 
 use super::CheckAccount;
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct CheckAccounts {
     pub other_accounts_allowed: bool,
     pub accounts: BTreeMap<AddressKey, CheckAccount>,
@@ -31,3 +31,16 @@ impl InterpretableFrom<CheckAccountsRaw> for CheckAccounts {
         }
     }
 }
+
+impl IntoRaw<CheckAccountsRaw> for CheckAccounts {
+    fn into_raw(self) -> CheckAccountsRaw {
+        CheckAccountsRaw {
+            other_accounts_allowed: self.other_accounts_allowed,
+            accounts: self
+                .accounts
+                .into_iter()
+                .map(|(k, v)| (k.into_raw(), Box::new(v.into_raw())))
+                .collect(),
+        }
+    }
+}
