@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::{BigUintValue, BytesValue, CheckValue, CheckValueList, U64Value},
     serde_raw::CheckEsdtInstanceRaw,
 };
@@ -15,6 +15,19 @@ pub struct CheckEsdtInstance {
     pub attributes: CheckValue<BytesValue>,
 }
 
+impl CheckEsdtInstance {
+    pub fn is_simple_fungible(&self) -> bool {
+        let is_uri_star = matches!(self.uri, CheckValue::Star);
+
+        self.nonce.value == 0
+            && self.creator.is_star()
+            && self.royalties.is_star()
+            && self.hash.is_star()
+            && is_uri_star
+            && self.attributes.is_star()
+    }
+}
+
 impl InterpretableFrom<CheckEsdtInstanceRaw> for CheckEsdtInstance {
     fn interpret_from(from: CheckEsdtInstanceRaw, context: &InterpreterContext) -> Self {
         CheckEsdtInstance {
@@ -28,3 +41,17 @@ impl InterpretableFrom<CheckEsdtInstanceRaw> for CheckEsdtInstance {
         }
     }
 }
+
+impl IntoRaw<CheckEsdtInstanceRaw> for CheckEsdtInstance {
+    fn into_raw(self) -> CheckEsdtInstanceRaw {
+        CheckEsdtInstanceRaw {
+            nonce: self.nonce.into_raw(),
+            balance: self.balance.into_raw(),
+            creator: self.creator.into_raw(),
+            royalties: self.royalties.into_raw(),
+            hash: self.hash.into_raw(),
+            uri: self.uri.into_raw(),
+            attributes: self.attributes.into_raw(),
+        }
+    }
+}
