@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     serde_raw::CheckEsdtInstancesRaw,
 };
 
@@ -50,3 +50,14 @@ impl InterpretableFrom<CheckEsdtInstancesRaw> for CheckEsdtInstances {
         }
     }
 }
+
+impl IntoRaw<CheckEsdtInstancesRaw> for CheckEsdtInstances {
+    fn into_raw(self) -> CheckEsdtInstancesRaw {
+        match self {
+            CheckEsdtInstances::Equal(eq) => {
+                CheckEsdtInstancesRaw::Equal(eq.into_iter().map(|cei| cei.into_raw()).collect())
+            },
+            CheckEsdtInstances::Star => CheckEsdtInstancesRaw::Star,
+        }
+    }
+}
