@@ -2,18 +2,18 @@ mod esdt;
 mod esdt_check;
 mod esdt_data_check;
 mod esdt_instance;
-mod esdt_instances;
+mod esdt_instance_check;
+mod esdt_instances_check;
 mod esdt_map_check;
 mod esdt_map_contents_check;
 mod esdt_object;
-mod instance;
 
 pub use esdt::*;
 pub use esdt_check::*;
 pub use esdt_data_check::*;
 pub use esdt_instance::*;
-pub use esdt_instances::*;
+pub use esdt_instance_check::*;
+pub use esdt_instances_check::*;
 pub use esdt_map_check::*;
 pub use esdt_map_contents_check::*;
 pub use esdt_object::*;
-pub use instance::*;
