@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     serde_raw::CheckStorageRaw,
 };
 
@@ -11,6 +11,12 @@ pub enum CheckStorage {
     Equal(CheckStorageDetails),
 }
 
+impl Default for CheckStorage {
+    fn default() -> Self {
+        CheckStorage::Star
+    }
+}
+
 impl CheckStorage {
     pub fn is_star(&self) -> bool {
         matches!(self, CheckStorage::Star)
@@ -27,3 +33,12 @@ impl InterpretableFrom<CheckStorageRaw> for CheckStorage {
         }
     }
 }
+
+impl IntoRaw<CheckStorageRaw> for CheckStorage {
+    fn into_raw(self) -> CheckStorageRaw {
+        match self {
+            CheckStorage::Star => CheckStorageRaw::Star,
+            CheckStorage::Equal(details) => CheckStorageRaw::Equal(details.into_raw()),
+        }
+    }
+}
