@@ -1,12 +1,12 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     model::{AddressValue, BigUintValue, BytesValue, U64Value},
     serde_raw::TxDeployRaw,
 };
 
 use super::tx_interpret_util::interpret_egld_value;
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct TxDeploy {
     pub from: AddressValue,
     pub egld_value: BigUintValue,
@@ -32,3 +32,21 @@ impl InterpretableFrom<TxDeployRaw> for TxDeploy {
         }
     }
 }
+
+impl IntoRaw<TxDeployRaw> for TxDeploy {
+    fn into_raw(self) -> TxDeployRaw {
+        TxDeployRaw {
+            from: self.from.into_raw(),
+            value: None,
+            egld_value: self.egld_value.into_raw_opt(),
+            contract_code: self.contract_code.into_raw(),
+            arguments: self
+                .arguments
+                .into_iter()
+                .map(|arg| arg.into_raw())
+                .collect(),
+            gas_limit: self.gas_limit.into_raw(),
+            gas_price: self.gas_price.into_raw(),
+        }
+    }
+}
