@@ -1,5 +1,5 @@
 use crate::{
-    interpret_trait::{InterpretableFrom, InterpreterContext},
+    interpret_trait::{InterpretableFrom, InterpreterContext, IntoRaw},
     value_interpreter::interpret_string,
 };
 
@@ -57,6 +57,12 @@ impl InterpretableFrom<String> for U64Key {
     }
 }
 
+impl IntoRaw<String> for U64Key {
+    fn into_raw(self) -> String {
+        self.original
+    }
+}
+
 impl fmt::Display for U64Key {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         self.original.fmt(f)
